import { useMessage } from '/@/hooks/web/useMessage'
import { defHttp } from '/@/utils/http/axios'

const { createConfirm } = useMessage()

enum Api {
	list = '/dry/dryOrder/list',
	queryByEqp = 'dry/dry/queryByEqp',
	queryOrderTrendById = '/dry/dryOrder/queryOrderTrendById',
	save = '/dry/dryOrder/add',
	edit = '/dry/dryOrder/edit',
	deleteOne = '/dry/dryOrder/delete',
	deleteBatch = '/dry/dryOrder/deleteBatch',
	importExcel = '/dry/dryOrder/importExcel',
	exportXls = '/dry/dryOrder/exportXls',
}
/**
 * 导出api
 * @param params
 */
export const getExportUrl = Api.exportXls
/**
 * 导入api
 */
export const getImportUrl = Api.importExcel
/**
 * 列表接口
 * @param params
 */
export const list = (params) => defHttp.get({ url: Api.list, params })

/**
 * 查询机台当前工单
 * @param params
 */
export const queryByEqp = (params) => defHttp.get({ url: Api.queryByEqp, params })

/**
 * 删除单个
 */
export const deleteOne = (params, handleSuccess) => {
	return defHttp.delete({ url: Api.deleteOne, params }, { joinParamsToUrl: true }).then(() => {
		handleSuccess()
	})
}
/**
 * 批量删除
 * @param params
 */
export const batchDelete = (params, handleSuccess) => {
	createConfirm({
		iconType: 'warning',
		title: '确认删除',
		content: '是否删除选中数据',
		okText: '确认',
		cancelText: '取消',
		onOk: () => {
			return defHttp.delete({ url: Api.deleteBatch, data: params }, { joinParamsToUrl: true }).then(() => {
				handleSuccess()
			})
		},
	})
}
/**
 * 保存或者更新
 * @param params
 */
export const saveOrUpdate = (params, isUpdate) => {
	const url = isUpdate ? Api.edit : Api.save
	return defHttp.post({ url: url, params })
}


export const queryOrderTrendById = (params) => defHttp.get({url: Api.queryOrderTrendById, params})
